<template>
  <div class="app-container">

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="Plus"
          @click="handleAdd"
          v-hasPermi="['plant:add']"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="Edit"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['plant:edit']"
        >修改</el-button>
      </el-col>
<!--      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="Delete"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['aps_plant:aps_plant:remove']"
        >删除</el-button>
      </el-col>-->
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="Download"
          @click="handleExport"
          v-hasPermi="['plant:export']"
        >导出</el-button>
      </el-col>
      <right-toolbar :search="false" 
        @refreshTable="getList"
      ></right-toolbar>
    </el-row>

    <HxlhTable
        style="width: 100%"
        :columns="columns"
        :data="aps_plantList"
        :loading="loading"
        :height="height"
        :page="page"
        @changePageNo="changePageNo"
        @changePageSize="changePageSize"
        @on-checkbox="handleCheckboxChange"
    >
      <template #buttons="{row}">
        <vxe-button mode="text" @click="handleUpdate(row)" v-hasPermi="['plant:edit']" >编辑</vxe-button>
      </template>
    </HxlhTable>

    <!-- 添加或修改工厂管理对话框 -->
    <el-dialog :title="title" v-model="open" width="500px" append-to-body>
      <el-form ref="aps_plantRef" :model="form" :rules="rules" label-width="80px">

        <el-form-item label="工厂名称" prop="plantName">
          <el-input v-model="form.plantName" placeholder="请输入工厂名称" />
        </el-form-item>
        <el-form-item label="工厂编码" prop="plantCode">
          <el-input v-model="form.plantCode" placeholder="请输入工厂编码" :disabled=disabled />
        </el-form-item>
        <el-form-item label="启用状态" prop="status">
          <el-radio-group v-model="form.status">
            <el-radio
              v-for="dict in aps_plant_status"
              :key="dict.value"
              :label="dict.value"
            >{{dict.label}}</el-radio>
          </el-radio-group>
        </el-form-item>
      </el-form>
      <template #footer>
        <div class="dialog-footer">
          <el-button type="primary" @click="submitForm">确 定</el-button>
          <el-button @click="cancel">取 消</el-button>
        </div>
      </template>
    </el-dialog>
  </div>
</template>

<script setup name="Aps_plant">
import { listAps_plant, getAps_plant, delAps_plant, addAps_plant, updateAps_plant } from "@/api/basicData/plant";
import HxlhTable from '@/components/HxlhTable'

const { proxy } = getCurrentInstance();
const { aps_plant_status } = proxy.useDict('aps_plant_status');
const height = ref(document.documentElement.clientHeight - 170 + "px;");
const plantNameRules = ref(null);
const plantCodeRules = ref(null);
const dataForm = ref();
const aps_plantList = ref([]);
const open = ref(false);
const loading = ref(true);
const showSearch = ref(true);
const ids = ref([]);
const single = ref(true);
const multiple = ref(true);
const title = ref("");
const disabled = ref(false);
const data = reactive({
  form: {},
  queryParams: {
    pageNum: 1,
    pageSize: 10,
    plantName: null,
    plantCode: null,
    status: null,
  },
  rules: {
    plantName: [
      { required: true, message: "工厂名称不能为空", trigger: "blur" },
      {
        validator: async (rule, value, callback) => {
          if (!value) {
            return callback();
          }
          try {
            if(value === plantNameRules.value){
              callback();
            }else{
              const isExists = await checkPlantNameExists(value);
              if (isExists) {
                return callback(new Error('该工厂名称已存在，请更换'));
              } else {
                callback();
              }
            }
          } catch (error) {
            return callback(new Error('校验用户名时发生错误，请稍后重试'));
          }
        },
        trigger: 'blur'
      }
    ],
    plantCode: [
      { required: true, message: "工厂编码不能为空", trigger: "blur" },
      {
        validator: async (rule, value, callback) => {
          if (!value) {
            return callback();
          }
          try {
            if(value === plantCodeRules.value){
              callback();
            }else{
              const isExists = await checkPlantCodeExists(value);
              if (isExists) {
                return callback(new Error('该工厂编码已存在，请更换'));
              } else {
                callback();
              }
            }
          } catch (error) {
            return callback(new Error('校验用户名时发生错误，请稍后重试'));
          }
        },
        trigger: 'blur'
      }
    ],
    status: [
      { required: true, message: "启用状态不能为空", trigger: "blur" },
    ],
  }
});

const { queryParams, form, rules } = toRefs(data);

// 分页属性
const page = ref({
  total: 0,
  current: 1,
  size: 10
});

// 表格配置 
const columns = ref([
  { type: 'checkbox', width: 60, align:"center"},
  { type: 'seq', title: '序号', width: 60 },
  {
    title: '工厂名称',
    field: 'plantName',
  },
  {
    title: '工厂编码',
    field: 'plantCode',
  },
  {
    title: '启用状态',
    field: 'status',
  },
  {
    title: '创建者',
    field: 'createBy',
  },
  {
    title: '创建时间',
    field: 'createTime',
  },
  { title: '操作', width: 100, fixed:"right", slots: { default: 'buttons' } }
]);

/** 查询工厂管理列表 */
function getList() {
  loading.value = true;
  listAps_plant(queryParams.value).then(response => {
    aps_plantList.value = response.rows;
    page.value.total = response.total;
    loading.value = false;
  });
}

// 取消按钮
function cancel() {
  open.value = false;
  reset();
}

// 表单重置
function reset() {
  form.value = {
    id: null,
    plantName: null,
    plantCode: null,
    status: null,
    createBy: null,
    createTime: null,
    updateBy: null,
    updateTime: null
  };
  proxy.resetForm("aps_plantRef");
  plantNameRules.value = null;
  plantCodeRules.value = null;
}

/** 搜索按钮操作 */
function handleQuery() {
  page.value.current = 1;
  queryParams.value.pageNum = 1;
  getList();
}

/** 重置按钮操作 */
function resetQuery() {
  proxy.resetForm("queryRef");
  handleQuery();
}

// 多选框选中数据
function handleSelectionChange(selection) {
  ids.value = selection.map(item => item.id);
  single.value = selection.length != 1;
  multiple.value = !selection.length;
}

/** 新增按钮操作 */
function handleAdd() {
  reset();
  open.value = true;
  title.value = "添加工厂管理";
  disabled.value = false;
}

/** 修改按钮操作 */
function handleUpdate(row) {
  reset();
  const _id = row.id || ids.value
  disabled.value = true;
  getAps_plant(_id).then(response => {
    dataForm.value = response.data;
    form.value = response.data;
    open.value = true;
    title.value = "修改工厂管理";
    plantNameRules.value = form.value.plantName;
    plantCodeRules.value = form.value.plantCode;
  });
}

/** 提交按钮 */
const submitForm = async () => {
  await proxy.$refs["aps_plantRef"].validate(valid => {
    if (valid) {
      if (form.value.id != null) {
        updateAps_plant(form.value).then(response => {
          proxy.$modal.msgSuccess("修改成功");
          open.value = false;
          getList();
        });
      } else {
        addAps_plant(form.value).then(response => {
          proxy.$modal.msgSuccess("新增成功");
          open.value = false;
          getList();
        });
      }
    }
  });
}

/** 删除按钮操作 */
function handleDelete(row) {
  const _ids = row.id || ids.value;
  proxy.$modal.confirm('是否确认删除工厂数据？').then(function() {
    return delAps_plant(_ids);
  }).then(() => {
    getList();
    proxy.$modal.msgSuccess("删除成功");
  }).catch(() => {});
}

/** 导出按钮操作 */
function handleExport() {
  proxy.download('aps_plant/aps_plant/export', {
    ...queryParams.value
  }, `aps_plant_${new Date().getTime()}.xlsx`)
}

/** 检查工厂名字重复 */
const checkPlantNameExists = async (value) => {
  return new Promise((resolve) => {
    queryParams.value = {};
    queryParams.value.plantName = value;
    listAps_plant(queryParams.value).then(response => {
      if(response.total === 0){
        resolve(false);
      }else{
        resolve(true);
      }
    });
    queryParams.value = {};
  });
};

/** 检查工厂编码重复 */
const checkPlantCodeExists = async (value) => {
  return new Promise((resolve) => {
    queryParams.value = {};
    queryParams.value.plantCode = value;
    listAps_plant(queryParams.value).then(response => {
      if(response.total === 0){
        resolve(false);
      }else{
        resolve(true);
      }
    });
    queryParams.value = {};
  });
};

function changePageNo(currentPage) {
  queryParams.value.pageNum = currentPage;
  page.value.current = currentPage;
  getList();
}

function changePageSize(pageSize) {
  page.value.current = 1;
  queryParams.value.pageNum = 1;
  queryParams.value.pageSize = pageSize;
  getList();
}

// 多选框选中数据
const handleCheckboxChange = (data) => {
  ids.value = data.records.map(item => item.id);
  single.value = data.records.length != 1;
  multiple.value = !data.records.length;
};

getList();
</script>
